#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   X11-xft
version:                0.3.4
visibility:             public
id:                     X11-xft-0.3.4-JGao0F7ospv80yY0xwg9ng
key:                    X11-xft-0.3.4-JGao0F7ospv80yY0xwg9ng
license:                BSD-3-Clause
maintainer:             xmonad@haskell.org
author:                 Clemens Fruhwirth
synopsis:               Bindings to the Xft and some Xrender parts
description:
    A Haskell bindings to the X Font library. With it, Haskell X11
    applications can access high quality font renderings and provide
    fonts with anti-aliasing and subpixel rendering. The bindings
    also provide minimal bindings to Xrender parts.

category:               Graphics
abi:                    6efc4da18311d77fc6ac14c8a25c0816
exposed:                True
exposed-modules:        Graphics.X11.Xft Graphics.X11.Xrender
import-dirs:            /usr/lib/ghc-9.6.6/site-local/X11-xft-0.3.4
library-dirs:           /usr/lib/ghc-9.6.6/site-local/X11-xft-0.3.4 /usr/lib
library-dirs-static:    /usr/lib/ghc-9.6.6/site-local/X11-xft-0.3.4 /usr/lib
dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-x11-xft
hs-libraries:           HSX11-xft-0.3.4-JGao0F7ospv80yY0xwg9ng
extra-libraries:        Xft
extra-libraries-static:
    Xft Xrender X11 pthread xcb Xau Xdmcp fontconfig m expat m freetype
    dl bz2 png16 m m z brotlidec brotlicommon

include-dirs:
    /usr/include /usr/include/freetype2 /usr/include/libpng16

depends:
    X11-1.10.3-4bnVd3SdcvsJN8LDt8CJay base-4.18.2.1
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1

haddock-interfaces:     /usr/share/doc/haskell-x11-xft/html/X11-xft.haddock
haddock-html:           /usr/share/doc/haskell-x11-xft/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

